use strict;
use warnings;
use Test::More;
eval "use Test::Pod::Coverage 1.08";
plan skip_all => "Test::Pod::Coverage required for testing pod coverage" if $@;

plan tests => 1;
pod_coverage_ok(
    'Tk::Text::SuperText',
    { also_private => [
        qr/^ClassInit|Populate|variable$/,
        # and lots of TODOs
        qw/
            Backspace
            Button1
            DefaultEvents
            Delete
            KeySelect
            RemoveTextBinds
            ScrollPages
            SelectTo
            SetCursor
            autoIndentEnter
            backSpace
            bindDefault
            bindDelete
            copy
            cut
            del
            delete
            deleteLine
            deleteSelected
            deleteToLineEnd
            deleteToLineStart
            deleteToWordEnd
            deleteToWordStart
            deleteWord
            destroy
            enter
            escape
            findMatchingChar
            flashMatchingChar
            focusNext
            focusPrev
            getSelected
            getansi
            inlinePaste
            ins
            insert
            insertControlCode
            insertmode
            jumpToMatchingChar
            keyPress
            leftTab
            matchbackground
            matchforeground
            matchingcouples
            menuSelect
            mouseMoveInsert
            mouseMovePage
            mouseMovePageTo
            mousePasteSelection
            mouseRectSelection
            mouseSelect
            mouseSelectAdd
            mouseSelectAddLine
            mouseSelectAddWord
            mouseSelectAutoScan
            mouseSelectAutoScanStop
            mouseSelectChar
            mouseSelectLine
            mouseSelectWord
            mouseSetInsert
            moveDown
            moveDownParagraph
            moveLeft
            moveLeftWord
            moveLineEnd
            moveLineStart
            movePageDown
            movePageLeft
            movePageRight
            movePageUp
            moveRight
            moveRightWord
            moveTextEnd
            moveTextStart
            moveUp
            moveUpParagraph
            noAutoIndentEnter
            noOP
            redo
            removeMatch
            resetUndo
            selectAll
            selectDown
            selectDownParagraph
            selectLeft
            selectLeftWord
            selectRectDown
            selectRectLeft
            selectRectRight
            selectRectUp
            selectRight
            selectRightWord
            selectToLineEnd
            selectToLineStart
            selectToMark
            selectToPageDown
            selectToPageUp
            selectToTextEnd
            selectToTextStart
            selectUp
            selectUpParagraph
            selectionShiftLeft
            selectionShiftLeftTab
            selectionShiftRight
            selectionShiftRightTab
            setSelectionMark
        /
    ] },
    'Tk::Text::SuperText is covered',
);